@@ -196,6 +196,12 @@ def process_line(calc_line, local_ns):
 
     # `Pint` prefers exponents to the 1/2 power instead of square roots
     equation = alt_sqrt(equation)
+
+    # Handle manually inserted line breaks placed in the line by the user
+    description.replace('//', '////')
+    equation.replace('//', '')
+    latex_equation.replace('//', '////')
+    reference.replace('//', '////')
     
     # Turn off pretty printing momentarily while we prepare a Python expression for the value
     ureg.default_format = '~'
